@@ -1,7 +1,9 @@
 package Perinci::Examples::SahSchemas;
 
-our $DATE = '2018-01-15'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-14'; # DATE
+our $DIST = 'Perinci-Examples-SahSchemas'; # DIST
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -109,6 +111,36 @@ sub schema_date {
     [200, "OK", \%args];
 }
 
+$SPEC{schema_filesize} = {
+    v => 1.1,
+    args => {
+        mod => {
+            schema => 'filesize*',
+            req => 1,
+            pos => 0,
+        },
+    },
+};
+sub schema_filesize {
+    my %args = @_;
+    [200, "OK", \%args];
+}
+
+$SPEC{schema_bandwidth} = {
+    v => 1.1,
+    args => {
+        mod => {
+            schema => 'bandwidth*',
+            req => 1,
+            pos => 0,
+        },
+    },
+};
+sub schema_bandwidth {
+    my %args = @_;
+    [200, "OK", \%args];
+}
+
 1;
 # ABSTRACT: Example for using various schemas
 
@@ -124,16 +156,46 @@ Perinci::Examples::SahSchemas - Example for using various schemas
 
 =head1 VERSION
 
-This document describes version 0.002 of Perinci::Examples::SahSchemas (from Perl distribution Perinci-Examples-SahSchemas), released on 2018-01-15.
+This document describes version 0.003 of Perinci::Examples::SahSchemas (from Perl distribution Perinci-Examples-SahSchemas), released on 2020-03-14.
 
 =head1 FUNCTIONS
 
 
+=head2 schema_bandwidth
+
+Usage:
+
+ schema_bandwidth(%args) -> [status, msg, payload, meta]
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<mod>* => I<bandwidth>
+
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
 =head2 schema_date
 
 Usage:
 
- schema_date(%args) -> [status, msg, result, meta]
+ schema_date(%args) -> [status, msg, payload, meta]
 
 This function is not exported.
 
@@ -147,6 +209,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<time_moment> => I<date>
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -154,18 +217,19 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
 
 
+
 =head2 schema_dirname
 
 Usage:
 
- schema_dirname(%args) -> [status, msg, result, meta]
+ schema_dirname(%args) -> [status, msg, payload, meta]
 
 This function is not exported.
 
@@ -175,6 +239,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<mod>* => I<dirname>
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -182,18 +247,19 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
 
 
+
 =head2 schema_filename
 
 Usage:
 
- schema_filename(%args) -> [status, msg, result, meta]
+ schema_filename(%args) -> [status, msg, payload, meta]
 
 This function is not exported.
 
@@ -203,6 +269,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<mod>* => I<filename>
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -210,18 +277,49 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
 
 
+
+=head2 schema_filesize
+
+Usage:
+
+ schema_filesize(%args) -> [status, msg, payload, meta]
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<mod>* => I<filesize>
+
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
 =head2 schema_pathname
 
 Usage:
 
- schema_pathname(%args) -> [status, msg, result, meta]
+ schema_pathname(%args) -> [status, msg, payload, meta]
 
 This function is not exported.
 
@@ -231,6 +329,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<mod>* => I<pathname>
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -238,18 +337,19 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
 
 
+
 =head2 schema_perl_distname
 
 Usage:
 
- schema_perl_distname(%args) -> [status, msg, result, meta]
+ schema_perl_distname(%args) -> [status, msg, payload, meta]
 
 This function is not exported.
 
@@ -259,6 +359,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<mod>* => I<perl::distname>
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -266,18 +367,19 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
 
 
+
 =head2 schema_perl_modname
 
 Usage:
 
- schema_perl_modname(%args) -> [status, msg, result, meta]
+ schema_perl_modname(%args) -> [status, msg, payload, meta]
 
 This function is not exported.
 
@@ -287,6 +389,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<mod>* => I<perl::modname>
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -294,7 +397,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -322,7 +425,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
